==> juce-docs-7.0.8-1-aarch64.pkg.tar.xz: usr/share/doc/juce/html/search/functions_11.js <==
var searchData=
[
  ['quadraphonic_0',['quadraphonic',['../classAudioChannelSet.html#ab216c3d458cbd3965e321a29d12d591d',1,'AudioChannelSet']]],
  ['quadraticto_1',['quadraticto',['../classRelativePointPath_1_1QuadraticTo.html#aba89135707082499521af4acc13d8182',1,'RelativePointPath::QuadraticTo::QuadraticTo()'],['../classPath.html#ab50510cf385b9ea3fe64fef6be45f85b',1,'Path::quadraticTo(float controlPointX, float controlPointY, float endPointX, float endPointY)'],['../classPath.html#afc8df505c72587a7c973ec20e28e418c',1,'Path::quadraticTo(Point&lt; float &gt; controlPoint, Point&lt; float &gt; endPoint)']]],
  ['quarterframe_2',['quarterFrame',['../classMidiMessage.html#ab21def5ca28557f4d7df31c8425c3386',1,'MidiMessage']]],
  ['quaternion_3',['quaternion',['../classQuaternion.html#ab6cfa17954ad0cf303877c8b7d578cc2',1,'Quaternion::Quaternion() noexcept'],['../classQuaternion.html#a55df57ee8430a9b1b1581ace70e105e3',1,'Quaternion::Quaternion(const Quaternion &amp;other) noexcept'],['../classQuaternion.html#a80054cbe7779c1237c1d08f53077bd43',1,'Quaternion::Quaternion(Vector3D&lt; Type &gt; vectorPart, Type scalarPart) noexcept'],['../classQuaternion.html#a1b5dab7556226d76040277dc8ee3f0a4',1,'Quaternion::Quaternion(Type x, Type y, Type z, Type w) noexcept']]],
  ['queryiaudioprocessor_4',['queryIAudioProcessor',['../structVST3ClientExtensions.html#a59c5142f3d0b7d2a8d227cd1d3fb0f0b',1,'VST3ClientExtensions']]],
  ['queryieditcontroller_5',['queryIEditController',['../structVST3ClientExtensions.html#accda7661d727659ea6fe61e6e02030f0',1,'VST3ClientExtensions']]],
  ['queryinterface_6',['queryInterface',['../classActiveXControlComponent.html#ad79a5c7bebaffb582120d402f48219c1',1,'ActiveXControlComponent']]],
  ['quit_7',['quit',['../classJUCEApplicationBase.html#a542e212605f0aa693f687d8798998615',1,'JUCEApplicationBase']]],
  ['quoted_8',['quoted',['../classString.html#a59db7c96e9b9e6cfb39754c43c758026',1,'String']]]
];

==> juce-docs-7.0.9-1-aarch64.pkg.tar.xz: usr/share/doc/juce/html/search/functions_11.js <==
var searchData=
[
  ['quadraphonic_0',['quadraphonic',['../classAudioChannelSet.html#ab216c3d458cbd3965e321a29d12d591d',1,'AudioChannelSet']]],
  ['quadraticto_1',['quadraticto',['../classPath.html#ab50510cf385b9ea3fe64fef6be45f85b',1,'Path::quadraticTo(float controlPointX, float controlPointY, float endPointX, float endPointY)'],['../classPath.html#afc8df505c72587a7c973ec20e28e418c',1,'Path::quadraticTo(Point&lt; float &gt; controlPoint, Point&lt; float &gt; endPoint)'],['../classRelativePointPath_1_1QuadraticTo.html#aba89135707082499521af4acc13d8182',1,'RelativePointPath::QuadraticTo::QuadraticTo()']]],
  ['quarterframe_2',['quarterFrame',['../classMidiMessage.html#ab21def5ca28557f4d7df31c8425c3386',1,'MidiMessage']]],
  ['quaternion_3',['quaternion',['../classQuaternion.html#ab6cfa17954ad0cf303877c8b7d578cc2',1,'Quaternion::Quaternion() noexcept'],['../classQuaternion.html#a55df57ee8430a9b1b1581ace70e105e3',1,'Quaternion::Quaternion(const Quaternion &amp;other) noexcept'],['../classQuaternion.html#a80054cbe7779c1237c1d08f53077bd43',1,'Quaternion::Quaternion(Vector3D&lt; Type &gt; vectorPart, Type scalarPart) noexcept'],['../classQuaternion.html#a1b5dab7556226d76040277dc8ee3f0a4',1,'Quaternion::Quaternion(Type x, Type y, Type z, Type w) noexcept']]],
  ['queryiaudioprocessor_4',['queryIAudioProcessor',['../structVST3ClientExtensions.html#a59c5142f3d0b7d2a8d227cd1d3fb0f0b',1,'VST3ClientExtensions']]],
  ['queryieditcontroller_5',['queryIEditController',['../structVST3ClientExtensions.html#accda7661d727659ea6fe61e6e02030f0',1,'VST3ClientExtensions']]],
  ['queryinterface_6',['queryInterface',['../classActiveXControlComponent.html#ad79a5c7bebaffb582120d402f48219c1',1,'ActiveXControlComponent']]],
  ['quit_7',['quit',['../classJUCEApplicationBase.html#a542e212605f0aa693f687d8798998615',1,'JUCEApplicationBase']]],
  ['quoted_8',['quoted',['../classString.html#a59db7c96e9b9e6cfb39754c43c758026',1,'String']]]
];
